@@ -125,7 +125,55 @@ store_delete_object.tar_gcp <- function(store, name = NULL) {
   )
 }
 
-
+# TODO: implement like store_delete_objects.tar_aws() with true batching
+#   when https://github.com/cloudyr/googleCloudStorageR/issues/188 is solved.
+#' @export
+store_delete_objects.tar_gcp <- function(store, meta, batch_size, verbose) {
+  gcp <- store$resources$gcp
+  meta$bucket_group <- map_chr(
+    x = meta$path,
+    f = ~paste(
+      store_gcp_bucket(.x),
+      sep = "|"
+    )
+  )
+  for (group in unique(meta$bucket_group)) {
+    subset <- meta[meta$bucket_group == group,, drop = FALSE] # nolint
+    for (index in seq_len(nrow(subset))) {
+      example_path <- subset$path[[index]]
+      bucket <- store_gcp_bucket(example_path)
+      key <- store_gcp_key(example_path)
+      version <- store_gcp_version(example_path)
+      message <- paste(
+        "could not object %s from gcp bucket %s.",
+        "You may need to delete it manually.\nMessage: "
+      )
+      message <- sprintf(message, key, bucket)
+      if (verbose) {
+        tar_message_run(
+          sprintf(
+            "Deleting object %s%s in bucket %s",
+            key,
+            if_any(is.null(version), "", paste(" version", version)),
+            bucket
+          )
+        )
+      }
+      tryCatch(
+        gcp_gcs_delete(
+          key = key,
+          bucket =  bucket,
+          version = version,
+          verbose = gcp$verbose %|||% FALSE,
+          max_tries = gcp$max_tries %|||% 5L
+        ),
+        error = function(condition) {
+          tar_throw_validate(message, conditionMessage(condition))
+        }
+      )
+    }
+  }
+}
 
 #' @export
 store_upload_object.tar_gcp <- function(store) {
@@ -142,7 +190,6 @@ store_upload_object_gcp <- function(store) {
       file = store$file$stage,
       key = key,
       bucket = bucket,
-      metadata = list("targets-hash" = store$file$hash),
       predefined_acl = store$resources$gcp$predefined_acl %|||% "private",
       verbose = store$resources$gcp$verbose %|||% FALSE,
       max_tries = store$resources$gcp$max_tries %|||% 5L
@@ -162,13 +209,10 @@ store_upload_object_gcp <- function(store) {
     invert = TRUE
   )
   store$file$path <- c(path, paste0("version=", head$generation))
+  store$file$hash <- digest_chr64(head$md5)
   invisible()
 }
 
-#' @export
-store_ensure_correct_hash.tar_gcp <- function(store, storage, deployment) {
-}
-
 #' @export
 store_has_correct_hash.tar_gcp <- function(store) {
   hash <- store_gcp_hash(store = store)
@@ -176,15 +220,9 @@ store_has_correct_hash.tar_gcp <- function(store) {
 }
 
 store_gcp_hash <- function(store) {
-  path <- store$file$path
-  head <- gcp_gcs_head(
-    key = store_gcp_key(path),
-    bucket = store_gcp_bucket(path),
-    version = store_gcp_version(path),
-    verbose = store$resources$gcp$verbose %|||% FALSE,
-    max_tries = store$resources$gcp$max_tries %|||% 5L
-  )
-  head$metadata[["targets-hash"]]
+  tar_runtime$inventories$gcp <- tar_runtime$inventories$gcp %|||%
+    inventory_gcp_init()
+  tar_runtime$inventories$gcp$get_cache(store = store)
 }
 # nocov end
 
