@@ -5,7 +5,9 @@ outdated_init <- function(
   shortcut = FALSE,
   queue = "sequential",
   reporter = "silent",
-  seconds_interval = 0.5
+  seconds_meta_append = 0,
+  seconds_meta_upload = 15,
+  seconds_reporter = 0
 ) {
   outdated_new(
     pipeline = pipeline,
@@ -14,7 +16,9 @@ outdated_init <- function(
     shortcut = shortcut,
     queue = queue,
     reporter = reporter,
-    seconds_interval = seconds_interval,
+    seconds_meta_append = seconds_meta_append,
+    seconds_meta_upload = seconds_meta_upload,
+    seconds_reporter = seconds_reporter,
     checked = counter_init(),
     outdated = counter_init()
   )
@@ -27,7 +31,9 @@ outdated_new <- function(
   shortcut = NULL,
   queue = NULL,
   reporter = NULL,
-  seconds_interval = NULL,
+  seconds_meta_append = NULL,
+  seconds_meta_upload = NULL,
+  seconds_reporter = NULL,
   checked = NULL,
   outdated = NULL
 ) {
@@ -38,7 +44,9 @@ outdated_new <- function(
     shortcut = shortcut,
     queue = queue,
     reporter = reporter,
-    seconds_interval = seconds_interval,
+    seconds_meta_append = seconds_meta_append,
+    seconds_meta_upload = seconds_meta_upload,
+    seconds_reporter = seconds_reporter,
     checked = checked,
     outdated = outdated
   )
@@ -60,7 +68,9 @@ outdated_class <- R6::R6Class(
       shortcut = NULL,
       queue = NULL,
       reporter = NULL,
-      seconds_interval = NULL,
+      seconds_meta_append = NULL,
+      seconds_meta_upload = NULL,
+      seconds_reporter = NULL,
       checked = NULL,
       outdated = NULL
     ) {
@@ -71,7 +81,9 @@ outdated_class <- R6::R6Class(
         shortcut = shortcut,
         queue = queue,
         reporter = reporter,
-        seconds_interval = seconds_interval
+        seconds_meta_append = seconds_meta_append,
+        seconds_meta_upload = seconds_meta_upload,
+        seconds_reporter = seconds_reporter
       )
       self$checked <- checked
       self$outdated <- outdated
