@@ -10,7 +10,9 @@ runtime_new <- function(
   file_exist = NULL,
   file_info = NULL,
   file_info_exist = NULL,
-  nanonext = NULL
+  nanonext = NULL,
+  inventories = NULL,
+  traceback = NULL
 ) {
   force(target)
   force(frames)
@@ -24,6 +26,8 @@ runtime_new <- function(
   force(file_info)
   force(file_info_exist)
   force(nanonext)
+  force(inventories)
+  force(traceback)
   environment()
 }
 
@@ -78,6 +82,33 @@ runtime_validate <- function(x) {
     tar_assert_scalar(x$nanonext)
     tar_assert_lgl(x$nanonext)
   }
+  if (!is.null(x$inventories)) {
+    tar_assert_list(x$inventories)
+  }
+  if (!is.null(x$traceback)) {
+    tar_assert_chr(x$traceback)
+  }
+}
+
+runtime_set_file_info <- function(runtime, store) {
+  objects <- list.files(
+    path = path_objects_dir(store),
+    all.files = TRUE,
+    full.names = TRUE,
+    no.. = TRUE
+  )
+  file_info <- as.list(file_info(objects)[, c("size", "mtime_numeric")])
+  names(file_info$size) <- objects
+  names(file_info$mtime_numeric) <- objects
+  runtime$file_info <- file_info
+  runtime$file_exist <- tar_counter(names = objects)
+  runtime$file_info_exist <- tar_counter(names = objects)
+}
+
+runtime_reset <- function(x) {
+  for (field in names(x)) {
+    x[[field]] <- NULL
+  }
 }
 
 #' @title Get the `tar_runtime` object.
