@@ -1,5 +1,5 @@
-timestamp_positives_new <- function() {
-  timestamp_positives_class$new()
+timestamp_positives_new <- function(seconds_interval = NULL) {
+  timestamp_positives_class$new(seconds_interval = seconds_interval)
 }
 
 timestamp_positives_class <- R6::R6Class(
