@@ -8,11 +8,11 @@
 #' @param context RStudio API context from
 #'   `rstudioapi::getActiveDocumentContext()`.
 rstudio_addin_tar_load <- function(context = NULL) {
-  assert_package("rstudioapi")
+  tar_assert_package("rstudioapi")
   context <- context %||% rstudioapi::getActiveDocumentContext()
   target <- rstudio_symbol_at_cursor(context)
   if (!is.null(target)) {
-    cli_blue_bullet(paste("Loading target", target, "into global evironment."))
+    cli_blue_bullet(paste("Loading target", target, "into global environment."))
     env <- list(target = as.symbol(target))
     eval(substitute(targets::tar_load(target, envir = globalenv()), env = env))
   }
