@@ -16,6 +16,8 @@
 #' @param predefined_acl Character of length 1, user access
 #'   to the object. See `?googleCloudStorageR::gcs_upload`
 #'   for possible values. Defaults to `"private"`.
+#' @param max_tries Positive integer of length 1,
+#'   number of tries accessing a network resource on GCP.
 #' @param verbose Logical of length 1, whether to print
 #'   extra messages like progress bars during uploads
 #'   and downloads. Defaults to `FALSE`.
@@ -35,15 +37,20 @@ tar_resources_gcp <- function(
   bucket = targets::tar_option_get("resources")$gcp$bucket,
   prefix = targets::tar_option_get("resources")$gcp$prefix,
   predefined_acl = targets::tar_option_get("resources")$gcp$predefined_acl,
+  max_tries = targets::tar_option_get("resources")$gcp$max_tries,
   verbose = targets::tar_option_get("resources")$gcp$verbose
 ) {
-  prefix <- prefix %|||% targets::tar_path_objects_dir_cloud()
+  if (is.null(prefix)) {
+    tar_warn_prefix()
+    prefix <- path_store_default()
+  }
   predefined_acl <- predefined_acl %|||% "private"
   verbose <- verbose %|||% FALSE
   out <- resources_gcp_init(
     bucket = bucket,
     prefix = prefix,
     predefined_acl = predefined_acl,
+    max_tries = max_tries,
     verbose = verbose
   )
   resources_validate(out)
