@@ -1,8 +1,9 @@
-#' @title List started targets.
+#' @title Deprecated: list started targets.
 #' @export
-#' @family progress
-#' @description List targets whose progress is `"started"`.
-#' @return A character vector of started targets.
+#' @keywords internal
+#' @description Deprecated in favor of [tar_dispatched()] on 2023-12-04
+#'   (version 1.3.2.9004).
+#' @return A character vector of dispatched targets.
 #' @inheritParams tar_progress
 #' @param names Optional, names of the targets. If supplied, the
 #'   function restricts its output to these targets.
@@ -18,14 +19,18 @@
 #'   )
 #' }, ask = FALSE)
 #' tar_make()
-#' tar_started()
-#' tar_started(starts_with("y_")) # see also any_of()
+#' tar_dispatched()
+#' tar_dispatched(starts_with("y_")) # see also any_of()
 #' })
 #' }
 tar_started <- function(
   names = NULL,
   store = targets::tar_config_get("store")
 ) {
+  tar_warn_deprecate(
+    "tar_started() is deprecated in targets version >= 1.3.2.9004 ",
+    "(2021-12-04). Use tar_dispatched() instead."
+  )
   tar_assert_allow_meta("tar_started", store)
   progress <- progress_init(path_store = store)
   progress <- tibble::as_tibble(progress$database$read_condensed_data())
@@ -34,5 +39,5 @@ tar_started <- function(
   if (!is.null(names)) {
     progress <- progress[match(names, progress$name), , drop = FALSE] # nolint
   }
-  progress$name[progress$progress == "started"]
+  progress$name[progress$progress == "dispatched"]
 }
