@@ -9,7 +9,7 @@ tmpenv <- function(...) {
 }
 
 require_clustermq <- function() {
-  skip_if_not_installed("clustermq")
+  skip_if_not_installed("clustermq", minimum_version = "0.9.1")
   skip_if(Sys.getenv("TAR_SKIP_CLUSTERMQ") != "", "skipping clustermq tests")
 }
 
@@ -36,18 +36,3 @@ crew_test_sleep <- function() {
     Sys.sleep(2.25)
   }
 }
-
-# TODO: always test and bump required versions when the next
-# crew/mirai/nanonext are on CRAN.
-skip_if_low_dep_versions <- function() {
-  sufficient_versions <- rlang::is_installed(
-    pkg = c(
-      "crew (>= 0.2.1)",
-      "mirai (>= 0.8.7.9012)",
-      "nanonext (>= 0.8.3.9007)"
-    )
-  )
-  if (!sufficient_versions) {
-    skip("version of crew, mirai, or nanonext is too low")
-  }
-}
