@@ -26,12 +26,13 @@ tar_test("workerless deployment works", {
   pipeline <- pipeline_init(list(x, y, z))
   out <- clustermq_init(pipeline)
   out$run()
-  built <- names(out$scheduler$progress$built$envir)
-  expect_equal(built, character(0))
+  completed <- names(out$scheduler$progress$completed$envir)
+  expect_equal(completed, character(0))
 })
 
 tar_test("semi-workerless deployment works", {
   skip_cran()
+  skip_on_os("mac")
   skip_on_os("windows")
   skip_on_os("solaris")
   require_clustermq()
@@ -56,12 +57,13 @@ tar_test("semi-workerless deployment works", {
   pipeline <- pipeline_init(list(x, y, z))
   out <- clustermq_init(pipeline)
   out$run()
-  built <- names(out$scheduler$progress$built$envir)
-  expect_equal(built, character(0))
+  completed <- names(out$scheduler$progress$completed$envir)
+  expect_equal(completed, character(0))
 })
 
 tar_test("some targets up to date, some not", {
   skip_cran()
+  skip_on_os("mac")
   skip_on_os("windows")
   skip_on_os("solaris")
   require_clustermq()
@@ -82,7 +84,7 @@ tar_test("some targets up to date, some not", {
   # https://github.com/mschubert/clustermq/issues/269
   cmq <- clustermq_init(pipeline)
   suppressWarnings(cmq$run())
-  out <- names(cmq$scheduler$progress$built$envir)
+  out <- names(cmq$scheduler$progress$completed$envir)
   expect_equal(out, "y")
   value <- target_read_value(pipeline_get_target(pipeline, "y"))
   expect_equal(value$object, 2L)
@@ -90,6 +92,7 @@ tar_test("some targets up to date, some not", {
 
 tar_test("clustermq algo can skip targets", {
   skip_cran()
+  skip_on_os("mac")
   skip_on_os("windows")
   skip_on_os("solaris")
   require_clustermq()
@@ -111,13 +114,14 @@ tar_test("clustermq algo can skip targets", {
   cmq <- clustermq_init(pipeline)
   # https://github.com/mschubert/clustermq/issues/269
   suppressWarnings(cmq$run())
-  out <- names(cmq$scheduler$progress$built$envir)
+  out <- names(cmq$scheduler$progress$completed$envir)
   expect_equal(out, "x")
   expect_equal(tar_read(x), 1L)
 })
 
 tar_test("nontrivial common data", {
   skip_cran()
+  skip_on_os("mac")
   skip_on_os("windows")
   skip_on_os("solaris")
   skip_on_covr()
@@ -152,6 +156,7 @@ tar_test("nontrivial common data", {
 
 tar_test("clustermq with a dynamic file", {
   skip_cran()
+  skip_on_os("mac")
   skip_on_os("windows")
   skip_on_os("solaris")
   skip_on_covr()
@@ -179,7 +184,7 @@ tar_test("clustermq with a dynamic file", {
   cmq <- clustermq_init(pipeline)
   # https://github.com/mschubert/clustermq/issues/269
   suppressWarnings(cmq$run())
-  out <- names(cmq$scheduler$progress$built$envir)
+  out <- names(cmq$scheduler$progress$completed$envir)
   expect_equal(out, "x")
   saveRDS(2L, pipeline_get_target(pipeline, "x")$store$file$path)
   x <- tar_target_raw("x", quote(save1()), format = "file")
@@ -187,12 +192,13 @@ tar_test("clustermq with a dynamic file", {
   cmq <- clustermq_init(pipeline)
   # https://github.com/mschubert/clustermq/issues/269
   suppressWarnings(cmq$run())
-  out <- names(cmq$scheduler$progress$built$envir)
+  out <- names(cmq$scheduler$progress$completed$envir)
   expect_equal(out, "x")
 })
 
 tar_test("branching plan", {
   skip_cran()
+  skip_on_os("mac")
   skip_on_os("windows")
   skip_on_os("solaris")
   require_clustermq()
@@ -211,8 +217,8 @@ tar_test("branching plan", {
   out2 <- clustermq_init(pipeline_map(), workers = 2L)
   # https://github.com/mschubert/clustermq/issues/269
   suppressWarnings(out2$run())
-  built <- names(out2$scheduler$progress$built$envir)
-  expect_equal(built, character(0))
+  completed <- names(out2$scheduler$progress$completed$envir)
+  expect_equal(completed, character(0))
   value <- function(name) {
     target_read_value(pipeline_get_target(pipeline, name))$object
   }
@@ -247,6 +253,7 @@ tar_test("branching plan", {
 
 tar_test("cover the worker shutdown step in clustermq$iterate() event loop", {
   skip_cran()
+  skip_on_os("mac")
   skip_on_os("windows")
   skip_on_os("solaris")
   require_clustermq()
