@@ -367,20 +367,20 @@ tar_test("fail to validate incompatible header", {
   )
 })
 
-tar_test("database queue", {
+tar_test("database buffer", {
   db <- database_init()
-  expect_null(db$queue)
+  expect_null(db$buffer)
   expect_equal(db$memory$names, character(0L))
-  db$enqueue_row(list(name = "x"))
+  db$buffer_row(list(name = "x"))
   expect_equal(db$memory$names, "x")
-  db$enqueue_row(list(name = "y"))
-  expect_equal(sort(db$queue), sort(c("x", "y")))
+  db$buffer_row(list(name = "y"))
+  expect_equal(sort(db$buffer), sort(c("x", "y")))
   expect_equal(sort(db$memory$names), sort(c("x", "y")))
   expect_false(file.exists(db$path))
-  db$dequeue_rows()
+  db$flush_rows()
   lines <- readLines(db$path)
   expect_equal(lines, c("x", "y"))
-  db$dequeue_rows()
+  db$flush_rows()
   lines <- readLines(db$path)
   expect_equal(lines, c("x", "y"))
 })
