@@ -30,7 +30,10 @@ tar_test("file_exists_stage() when the file does not exist", {
   expect_false(file_exists_stage(file))
 })
 
-tar_test("file_list_files()", {
+tar_test("file_list_files() without cache", {
+  old <- tar_runtime$file_exist
+  on.exit(tar_runtime$file_exist <- old)
+  tar_runtime$file_exist <- NULL
   dir.create("x")
   file.create(file.path("x", "y"))
   file.create(file.path("x", "z"))
@@ -50,6 +53,36 @@ tar_test("file_list_files()", {
   expect_equal(sort(out), sort(exp))
 })
 
+tar_test("file_list_files() with cache for some", {
+  old <- tar_runtime$file_exist
+  on.exit(tar_runtime$file_exist <- old)
+  tar_runtime$file_exist <- counter_init(names = "z")
+  dir.create("x")
+  file.create(file.path("x", "y"))
+  file.create(file.path("x", "z"))
+  dir.create("y")
+  file.create(file.path("y", "y"))
+  file.create(file.path("y", "z"))
+  file.create("z")
+  arg <- c("abc", "x", "y", "z")
+  out <- file_list_files(arg)
+  exp <- c(
+    "z",
+    file.path("x", "y"),
+    file.path("x", "z"),
+    file.path("y", "y"),
+    file.path("y", "z")
+  )
+  expect_equal(sort(out), sort(exp))
+})
+
+tar_test("file_list_files() with cache for all", {
+  old <- tar_runtime$file_exist
+  on.exit(tar_runtime$file_exist <- old)
+  tar_runtime$file_exist <- counter_init(names = c("a", "b"))
+  expect_equal(file_list_files(c("a", "b")), c("a", "b"))
+})
+
 tar_test("file_should_rehash()", {
   tmp <- tempfile()
   file <- file_init(path = tmp)
@@ -58,8 +91,7 @@ tar_test("file_should_rehash()", {
     file_should_rehash(
       file = file,
       time = file$time,
-      size = file$size,
-      bytes = file$bytes
+      size = file$size
     )
   )
 })
@@ -87,6 +119,27 @@ tar_test("file_update_hash()", {
   expect_equal(length(file$time), 1L)
 })
 
+tar_test("file_update_info()", {
+  tmp <- tempfile()
+  file <- file_init(path = tmp)
+  writeLines("xyz", tmp)
+  file_update_info(file)
+  expect_true(is.na(file$hash))
+  expect_gt(file$bytes, 0)
+  expect_true(is.character(file$time))
+  expect_true(grepl("^t", file$time))
+  expect_true(grepl("s$", file$time))
+  expect_false(anyNA(file_time_posixct(file$time)))
+  expect_true(inherits(file_time_posixct(file$time), "POSIXct"))
+  expect_true(is.character(file$size))
+  expect_equal(nchar(file$size), 16L)
+  expect_true(is.numeric(file$bytes))
+  expect_true(is.finite(file$bytes))
+  expect_equal(length(file$bytes), 1L)
+  expect_equal(length(file$time), 1L)
+  expect_equal(length(file$time), 1L)
+})
+
 tar_test("file_update_hash() where two files exist", {
   tmp <- c(tempfile(), tempfile())
   file <- file_init(path = tmp)
