@@ -14,8 +14,8 @@ tar_test("tar_destroy('cloud')", {
   skip_cran()
   pipeline <- pipeline_init(list(target_init("x", quote(0))))
   local_init(pipeline)$run()
-  dir_create(path_scratch_dir_cloud())
-  x <- file.path(path_scratch_dir_cloud(), "x")
+  dir_create(path_scratch_dir_network())
+  x <- file.path(path_scratch_dir_network(), "x")
   file.create(x)
   expect_true(file.exists(x))
   expect_true(file.exists("_targets"))
