@@ -20,3 +20,19 @@ tar_test("tar_source()", {
   tar_make(callr_function = NULL)
   expect_equal(tar_read(x), 5L)
 })
+
+tar_test("tar_source() with the change_directory argument", {
+  skip_cran()
+  wd <- getwd()
+  dir.create("y")
+  dir.create(file.path("y", "z"))
+  writeLines("wd <- getwd()", file.path("y", "z", "i.R"))
+  envir <- new.env()
+  expect_equal(getwd(), wd)
+  tar_source("y", envir = envir)
+  expect_equal(getwd(), wd)
+  expect_equal(envir$wd, getwd())
+  tar_source("y", change_directory = TRUE, envir = envir)
+  expect_equal(getwd(), wd)
+  expect_equal(envir$wd, file.path(getwd(), "y", "z"))
+})
